@@ -1,12 +1,27 @@
 #' Spread a key-value pair across multiple columns.
 #'
-#' @param key The bare (unquoted) name of the column whose values will be used
-#'   as column headings.
-#' @param value The bare (unquoted) name of the column whose values will
-#'  populate the cells.
-#' @inheritParams spread_
-#' @seealso \code{\link{spread_}} for a version that uses regular evaluation
-#'   and is suitable for programming with.
+#' @param data A data frame.
+#' @param key,value Column names or positions. This is passed to
+#'   [tidyselect::vars_pull()].
+#'
+#'   These arguments are passed by expression and support
+#'   [quasiquotation][rlang::quasiquotation] (you can unquote column
+#'   names or column positions).
+#' @param fill If set, missing values will be replaced with this value. Note
+#'   that there are two types of missingness in the input: explicit missing
+#'   values (i.e. `NA`), and implicit missings, rows that simply aren't
+#'   present. Both types of missing value will be replaced by `fill`.
+#' @param convert If `TRUE`, [type.convert()] with \code{asis =
+#'   TRUE} will be run on each of the new columns. This is useful if the value
+#'   column was a mix of variables that was coerced to a string. If the class of
+#'   the value column was factor or date, note that will not be true of the new
+#'   columns that are produced, which are coerced to character before type
+#'   conversion.
+#' @param drop If `FALSE`, will keep factor levels that don't appear in the
+#'   data, filling in missing combinations with `fill`.
+#' @param sep If `NULL`, the column names will be taken from the values of
+#'   `key` variable. If non-`NULL`, the column names will be given
+#'   by "<key_name><sep><key_value>".
 #' @export
 #' @examples
 #' library(dplyr)
@@ -30,60 +45,35 @@
 #'                  value = c(5.1, "setosa", 1, 7.0, "versicolor", 2))
 #' df %>% spread(var, value) %>% str
 #' df %>% spread(var, value, convert = TRUE) %>% str
-spread <- function(data, key, value, fill = NA, convert = FALSE, drop = TRUE,
-                   sep = NULL) {
-  key_col <- col_name(substitute(key))
-  value_col <- col_name(substitute(value))
-
-  spread_(data, key_col, value_col, fill = fill, convert = convert, drop = drop,
-    sep = sep)
+spread <- function(data, key, value, fill = NA, convert = FALSE,
+                   drop = TRUE, sep = NULL) {
+  UseMethod("spread")
 }
-
-#' Standard-evaluation version of \code{spread}.
-#'
-#' This is a S3 generic.
-#'
-#' @param data A data frame.
-#' @param key_col,value_col Strings giving names of key and value cols.
-#' @param fill If set, missing values will be replaced with this value. Note
-#'   that there are two types of missingness in the input: explicit missing
-#'   values (i.e. \code{NA}), and implicit missings, rows that simply aren't
-#'   present. Both types of missing value will be replaced by \code{fill}.
-#' @param convert If \code{TRUE}, \code{\link{type.convert}} with \code{asis =
-#'   TRUE} will be run on each of the new columns. This is useful if the value
-#'   column was a mix of variables that was coerced to a string. If the class of
-#'   the value column was factor or date, note that will not be true of the new
-#'   columns that are produced, which are coerced to character before type
-#'   conversion.
-#' @param drop If \code{FALSE}, will keep factor levels that don't appear in the
-#'   data, filling in missing combinations with \code{fill}.
-#' @param sep If \code{NULL}, the column names will be taken from the values of
-#'   \code{key} variable. If non-\code{NULL}, the column names will be given
-#'   by "<key_name><sep><key_value>".
-#' @keywords internal
 #' @export
-spread_ <- function(data, key_col, value_col, fill = NA, convert = FALSE,
-                    drop = TRUE, sep = NULL) {
-  if (!(key_col %in% names(data))) {
-    stop("Key column '", key_col, "' does not exist in input.", call. = FALSE)
-  }
-  if (!(value_col %in% names(data))) {
-    stop("Value column '", value_col, "' does not exist in input.", call. = FALSE)
-  }
-
-  UseMethod("spread_")
+spread.default <- function(data, key, value, fill = NA, convert = FALSE,
+                           drop = TRUE, sep = NULL) {
+  key <- compat_as_lazy(enquo(key))
+  value <- compat_as_lazy(enquo(value))
+  spread_(data,
+    key_col = key,
+    value_col = value,
+    fill = fill,
+    convert = convert,
+    drop = drop,
+    sep = sep
+  )
 }
-
 #' @export
-#' @importFrom tibble as_data_frame
-spread_.data.frame <- function(data, key_col, value_col, fill = NA,
-                               convert = FALSE, drop = TRUE, sep = NULL) {
+spread.data.frame <- function(data, key, value, fill = NA, convert = FALSE,
+                              drop = TRUE, sep = NULL) {
+  key_var <- tidyselect::vars_pull(names(data), !! enquo(key))
+  value_var <- tidyselect::vars_pull(names(data), !! enquo(value))
 
-  col <- data[key_col]
+  col <- data[key_var]
   col_id <- id(col, drop = drop)
   col_labels <- split_labels(col, col_id, drop = drop)
 
-  rows <- data[setdiff(names(data), c(key_col, value_col))]
+  rows <- data[setdiff(names(data), c(key_var, value_var))]
   if (length(rows) == 0) {
     # Special case when there's only one row
     row_id <- structure(1L, n = 1L)
@@ -99,13 +89,11 @@ spread_.data.frame <- function(data, key_col, value_col, fill = NA,
   # Check that each output value occurs in unique location
   if (anyDuplicated(overall)) {
     groups <- split(seq_along(overall), overall)
-    groups <- groups[vapply(groups, length, integer(1)) > 1]
+    groups <- groups[map_int(groups, length) > 1]
 
-    str <- vapply(groups, function(x) paste0("(", paste0(x, collapse = ", "), ")"),
-      character(1))
-
-    stop("Duplicate identifiers for rows ", paste(str, collapse = ", "),
-      call. = FALSE)
+    str <- map_chr(groups, function(x) paste0("(", paste0(x, collapse = ", "), ")"))
+    rows <- paste(str, collapse = ", ")
+    abort(glue("Duplicate identifiers for rows {rows}"))
   }
 
   # Add in missing values, if necessary
@@ -115,54 +103,41 @@ spread_.data.frame <- function(data, key_col, value_col, fill = NA,
     overall <- order(overall)
   }
 
-  value <- data[[value_col]]
+  value <- data[[value_var]]
   ordered <- value[overall]
   if (!is.na(fill)) {
     ordered[is.na(ordered)] <- fill
   }
 
-  if (convert && !is.character(ordered)) {
+  if (convert && !is_character(ordered)) {
     ordered <- as.character(ordered)
   }
   dim(ordered) <- c(attr(row_id, "n"), attr(col_id, "n"))
   colnames(ordered) <- enc2utf8(col_names(col_labels, sep = sep))
 
-  ordered <- as_data_frame_matrix(ordered)
+  ordered <- as_tibble_matrix(ordered)
 
   if (convert) {
-    ordered[] <- lapply(ordered, type.convert, as.is = TRUE)
+    ordered[] <- map(ordered, type.convert, as.is = TRUE)
   }
 
-  append_df(row_labels, ordered)
+  out <- append_df(row_labels, ordered)
+  reconstruct_tibble(data, out, c(key_var, value_var))
 }
 
 col_names <- function(x, sep = NULL) {
   names <- as.character(x[[1]])
 
-  if (is.null(sep)) {
-    ifelse(is.na(names), "<NA>", names)
+  if (is_null(sep)) {
+    ifelse(are_na(names), "<NA>", names)
   } else {
     paste(names(x)[[1]], names, sep = sep)
   }
 }
-
-as_data_frame_matrix <- function(x) {
+as_tibble_matrix <- function(x) {
   # getS3method() only available in R >= 3.3
-  get("as_data_frame.matrix", asNamespace("tibble"), mode = "function")(x)
+  get("as_tibble.matrix", asNamespace("tibble"), mode = "function")(x)
 }
-
-#' @export
-spread_.tbl_df <- function(data, key_col, value_col, fill = NA,
-                           convert = FALSE, drop = TRUE, sep = NULL) {
-  as_data_frame(NextMethod())
-}
-
-#' @export
-spread_.grouped_df <- function(data, key_col, value_col, fill = NA,
-                               convert = FALSE, drop = TRUE, sep = NULL) {
-  regroup(NextMethod(), data, c(key_col, value_col))
-}
-
 split_labels <- function(df, id, drop = TRUE) {
   if (length(df) == 0) {
     return(df)
@@ -172,11 +147,10 @@ split_labels <- function(df, id, drop = TRUE) {
     representative <- match(sort(unique(id)), id)
     df[representative, , drop = FALSE]
   } else {
-    unique_values <- lapply(df, ulevels)
+    unique_values <- map(df, ulevels)
     rev(expand.grid(rev(unique_values), stringsAsFactors = FALSE))
   }
 }
-
 ulevels <- function(x) {
   if (is.factor(x)) {
     x <- addNA(x, ifany = TRUE)
@@ -186,3 +160,28 @@ ulevels <- function(x) {
     sort(unique(x))
   }
 }
+
+
+#' @rdname deprecated-se
+#' @inheritParams spread
+#' @param key_col,value_col Strings giving names of key and value cols.
+#' @export
+spread_ <- function(data, key_col, value_col, fill = NA, convert = FALSE,
+                    drop = TRUE, sep = NULL) {
+  UseMethod("spread_")
+}
+#' @export
+spread_.data.frame <- function(data, key_col, value_col, fill = NA,
+                               convert = FALSE, drop = TRUE, sep = NULL) {
+  key_col <- compat_lazy(key_col, caller_env())
+  value_col <- compat_lazy(value_col, caller_env())
+
+  spread(data,
+    key = !! key_col,
+    value = !! value_col,
+    fill = fill,
+    convert = convert,
+    drop = drop,
+    sep = sep
+  )
+}
