@@ -20,17 +20,15 @@ test_that("match failures give NAs", {
 })
 
 test_that("extract keeps characters as character", {
-  df <- data_frame(x = "X-1")
-
+  df <- tibble(x = "X-1")
   out <- extract(df, x, c("x", "y"), "(.)-(.)", convert = TRUE)
   expect_equal(out$x, "X")
   expect_equal(out$y, 1L)
 })
 
 test_that("groups are preserved", {
-  df <- data_frame(g = 1, x = "X1") %>% dplyr::group_by(g)
+  df <- tibble(g = 1, x = "X1") %>% dplyr::group_by(g)
   rs <- df %>% extract(x, c("x", "y"), "(.)(.)")
-
   expect_equal(class(df), class(rs))
   expect_equal(dplyr::groups(df), dplyr::groups(rs))
 })
